"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const api = require("../../../scw/api.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const resourcePaginator = require("../../../scw/fetch/resource-paginator.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
class API extends api.API {
  pageOfListConsumptions = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2beta1/consumptions`,
      urlParams: marshalling.urlParams(
        ["billing_period", request.billingPeriod],
        ["category_name", request.categoryName],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ...Object.entries(
          marshalling.resolveOneOf([
            {
              default: this.client.settings.defaultOrganizationId,
              param: "organization_id",
              value: request.organizationId
            },
            {
              default: this.client.settings.defaultProjectId,
              param: "project_id",
              value: request.projectId
            }
          ])
        )
      )
    },
    marshalling_gen.unmarshalListConsumptionsResponse
  );
  /**
   * Get monthly consumption. Consumption allows you to retrieve your past or
   * current consumption cost, by project or category.
   *
   * @param request - The request {@link ListConsumptionsRequest}
   * @returns A Promise of ListConsumptionsResponse
   */
  listConsumptions = (request = {}) => resourcePaginator.enrichForPagination("consumptions", this.pageOfListConsumptions, request);
  pageOfListTaxes = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2beta1/taxes`,
      urlParams: marshalling.urlParams(
        ["billing_period", request.billingPeriod],
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListTaxesResponse
  );
  /**
   * Get monthly consumption taxes. Consumption Tax allows you to retrieve your
   * past or current tax charges, by project or category.
   *
   * @param request - The request {@link ListTaxesRequest}
   * @returns A Promise of ListTaxesResponse
   */
  listTaxes = (request = {}) => resourcePaginator.enrichForPagination("taxes", this.pageOfListTaxes, request);
  pageOfListInvoices = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2beta1/invoices`,
      urlParams: marshalling.urlParams(
        ["billing_period_start_after", request.billingPeriodStartAfter],
        ["billing_period_start_before", request.billingPeriodStartBefore],
        ["invoice_type", request.invoiceType],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListInvoicesResponse
  );
  /**
   * List invoices. List all your invoices, filtering by `start_date` and
   * `invoice_type`. Each invoice has its own ID.
   *
   * @param request - The request {@link ListInvoicesRequest}
   * @returns A Promise of ListInvoicesResponse
   */
  listInvoices = (request = {}) => resourcePaginator.enrichForPagination("invoices", this.pageOfListInvoices, request);
  /**
   * Export invoices. Export invoices in a CSV file.
   *
   * @param request - The request {@link ExportInvoicesRequest}
   * @returns A Promise of Blob
   */
  exportInvoices = (request = {}) => this.client.fetch({
    method: "GET",
    path: `/billing/v2beta1/export-invoices`,
    urlParams: marshalling.urlParams(
      ["dl", 1],
      ["billing_period_start_after", request.billingPeriodStartAfter],
      ["billing_period_start_before", request.billingPeriodStartBefore],
      ["file_type", request.fileType],
      ["invoice_type", request.invoiceType],
      ["order_by", request.orderBy],
      ["organization_id", request.organizationId],
      ["page", request.page],
      ["page_size", request.pageSize ?? this.client.settings.defaultPageSize]
    ),
    responseType: "blob"
  });
  /**
   * Get an invoice. Get a specific invoice, specified by its ID.
   *
   * @param request - The request {@link GetInvoiceRequest}
   * @returns A Promise of Invoice
   */
  getInvoice = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2beta1/invoices/${marshalling.validatePathParam("invoiceId", request.invoiceId)}`
    },
    marshalling_gen.unmarshalInvoice
  );
  /**
   * Download an invoice. Download a specific invoice, specified by its ID.
   *
   * @param request - The request {@link DownloadInvoiceRequest}
   * @returns A Promise of Blob
   */
  downloadInvoice = (request) => this.client.fetch({
    method: "GET",
    path: `/billing/v2beta1/invoices/${marshalling.validatePathParam("invoiceId", request.invoiceId)}/download`,
    urlParams: marshalling.urlParams(["dl", 1], ["file_type", request.fileType]),
    responseType: "blob"
  });
  pageOfListDiscounts = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/billing/v2beta1/discounts`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListDiscountsResponse
  );
  /**
   * List discounts. List all discounts for your Organization and usable
   * categories, products, offers, references, regions and zones where the
   * discount can be applied. As a reseller:
   *
   * - If you do not specify an `organization_id` you will list the discounts
   *   applied to your own Organization and your customers
   * - If you indicate your `organization_id` you will list only the discounts
   *   applied to your Organization
   * - If you indicate `the organization_id` of one of your customers, you will
   *   list the discounts applied to their Organization.
   *
   * @param request - The request {@link ListDiscountsRequest}
   * @returns A Promise of ListDiscountsResponse
   */
  listDiscounts = (request = {}) => resourcePaginator.enrichForPagination("discounts", this.pageOfListDiscounts, request);
}
exports.API = API;
