import { API as ParentAPI } from '../../../bridge';
import type { Region as ScwRegion } from '../../../bridge';
import type { AlertManager, ContactPoint, DataSource, GetConfigResponse, GlobalApiCreateGrafanaUserRequest, GlobalApiDeleteGrafanaUserRequest, GlobalApiGetCurrentPlanRequest, GlobalApiGetGrafanaProductDashboardRequest, GlobalApiGetGrafanaRequest, GlobalApiListGrafanaProductDashboardsRequest, GlobalApiListGrafanaUsersRequest, GlobalApiListPlansRequest, GlobalApiResetGrafanaUserPasswordRequest, GlobalApiSelectPlanRequest, GlobalApiSyncGrafanaDataSourcesRequest, Grafana, GrafanaProductDashboard, GrafanaUser, ListAlertsResponse, ListContactPointsResponse, ListDataSourcesResponse, ListGrafanaProductDashboardsResponse, ListGrafanaUsersResponse, ListPlansResponse, ListTokensResponse, Plan, RegionalApiCreateContactPointRequest, RegionalApiCreateDataSourceRequest, RegionalApiCreateTokenRequest, RegionalApiDeleteContactPointRequest, RegionalApiDeleteDataSourceRequest, RegionalApiDeleteTokenRequest, RegionalApiDisableAlertManagerRequest, RegionalApiDisableManagedAlertsRequest, RegionalApiEnableAlertManagerRequest, RegionalApiEnableManagedAlertsRequest, RegionalApiGetAlertManagerRequest, RegionalApiGetConfigRequest, RegionalApiGetDataSourceRequest, RegionalApiGetTokenRequest, RegionalApiGetUsageOverviewRequest, RegionalApiListAlertsRequest, RegionalApiListContactPointsRequest, RegionalApiListDataSourcesRequest, RegionalApiListTokensRequest, RegionalApiTriggerTestAlertRequest, RegionalApiUpdateContactPointRequest, RegionalApiUpdateDataSourceRequest, Token, UsageOverview } from './types.gen';
/**
 * Cockpit Global API.
 *
 * The Cockpit Global API allows you to manage your Cockpit's Grafana and plans.
 */
export declare class GlobalAPI extends ParentAPI {
    /**
     * Get your Cockpit's Grafana. Retrieve information on your Cockpit's Grafana,
     * specified by the ID of the Project the Cockpit belongs to. The output
     * returned displays the URL to access your Cockpit's Grafana.
     *
     * @param request - The request {@link GlobalApiGetGrafanaRequest}
     * @returns A Promise of Grafana
     */
    getGrafana: (request?: Readonly<GlobalApiGetGrafanaRequest>) => Promise<Grafana>;
    /**
     * Synchronize Grafana data sources. Trigger the synchronization of all your
     * data sources and the alert manager in the relevant regions. The alert
     * manager will only be synchronized if you have enabled it.
     *
     * @param request - The request {@link GlobalApiSyncGrafanaDataSourcesRequest}
     */
    syncGrafanaDataSources: (request?: Readonly<GlobalApiSyncGrafanaDataSourcesRequest>) => Promise<void>;
    /**
     * Create a Grafana user. Create a Grafana user to connect to your Cockpit's
     * Grafana. Upon creation, your user password displays only once, so make sure
     * that you save it. Each Grafana user is associated with a role: viewer or
     * editor. A viewer can only view dashboards, whereas an editor can create and
     * edit dashboards. Note that the `admin` username is not available for
     * creation.
     *
     * @param request - The request {@link GlobalApiCreateGrafanaUserRequest}
     * @returns A Promise of GrafanaUser
     */
    createGrafanaUser: (request: Readonly<GlobalApiCreateGrafanaUserRequest>) => Promise<GrafanaUser>;
    protected pageOfListGrafanaUsers: (request?: Readonly<GlobalApiListGrafanaUsersRequest>) => Promise<ListGrafanaUsersResponse>;
    /**
     * List Grafana users. List all Grafana users created in your Cockpit's
     * Grafana. By default, the Grafana users returned in the list are ordered in
     * ascending order.
     *
     * @param request - The request {@link GlobalApiListGrafanaUsersRequest}
     * @returns A Promise of ListGrafanaUsersResponse
     */
    listGrafanaUsers: (request?: Readonly<GlobalApiListGrafanaUsersRequest>) => Promise<ListGrafanaUsersResponse> & {
        all: () => Promise<GrafanaUser[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<GrafanaUser[], void, void>;
    };
    /**
     * Delete a Grafana user. Delete a Grafana user from your Cockpit's Grafana,
     * specified by the ID of the Project the Cockpit belongs to, and the ID of
     * the Grafana user.
     *
     * @param request - The request {@link GlobalApiDeleteGrafanaUserRequest}
     */
    deleteGrafanaUser: (request: Readonly<GlobalApiDeleteGrafanaUserRequest>) => Promise<void>;
    /**
     * Reset a Grafana user password. Reset the password of a Grafana user,
     * specified by the ID of the Project the Cockpit belongs to, and the ID of
     * the Grafana user. A new password regenerates and only displays once. Make
     * sure that you save it.
     *
     * @param request - The request
     *   {@link GlobalApiResetGrafanaUserPasswordRequest}
     * @returns A Promise of GrafanaUser
     */
    resetGrafanaUserPassword: (request: Readonly<GlobalApiResetGrafanaUserPasswordRequest>) => Promise<GrafanaUser>;
    protected pageOfListGrafanaProductDashboards: (request?: Readonly<GlobalApiListGrafanaProductDashboardsRequest>) => Promise<ListGrafanaProductDashboardsResponse>;
    /**
     * List Scaleway resources dashboards. Retrieve a list of available dashboards
     * in Grafana, for all Scaleway resources which are integrated with Cockpit.
     *
     * @param request - The request
     *   {@link GlobalApiListGrafanaProductDashboardsRequest}
     * @returns A Promise of ListGrafanaProductDashboardsResponse
     */
    listGrafanaProductDashboards: (request?: Readonly<GlobalApiListGrafanaProductDashboardsRequest>) => Promise<ListGrafanaProductDashboardsResponse> & {
        all: () => Promise<GrafanaProductDashboard[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<GrafanaProductDashboard[], void, void>;
    };
    /**
     * Get Scaleway resource dashboard. Retrieve information about the dashboard
     * of a Scaleway resource in Grafana, specified by the ID of the Project the
     * Cockpit belongs to, and the name of the dashboard.
     *
     * @param request - The request
     *   {@link GlobalApiGetGrafanaProductDashboardRequest}
     * @returns A Promise of GrafanaProductDashboard
     */
    getGrafanaProductDashboard: (request: Readonly<GlobalApiGetGrafanaProductDashboardRequest>) => Promise<GrafanaProductDashboard>;
    protected pageOfListPlans: (request?: Readonly<GlobalApiListPlansRequest>) => Promise<ListPlansResponse>;
    /**
     * List plan types. Retrieve a list of available pricing plan types.
     * Deprecated, retention is now managed at the data source level.
     *
     * @deprecated
     * @param request - The request {@link GlobalApiListPlansRequest}
     * @returns A Promise of ListPlansResponse
     */
    listPlans: (request?: Readonly<GlobalApiListPlansRequest>) => Promise<ListPlansResponse> & {
        all: () => Promise<Plan[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Plan[], void, void>;
    };
    /**
     * Apply a pricing plan. Apply a pricing plan on a given Project. You must
     * specify the ID of the pricing plan type. Note that you will be billed for
     * the plan you apply. Deprecated, retention is now managed at the data source
     * level.
     *
     * @deprecated
     * @param request - The request {@link GlobalApiSelectPlanRequest}
     * @returns A Promise of Plan
     */
    selectPlan: (request?: Readonly<GlobalApiSelectPlanRequest>) => Promise<Plan>;
    /**
     * Get current plan. Retrieve a pricing plan for the given Project, specified
     * by the ID of the Project. Deprecated, retention is now managed at the data
     * source level.
     *
     * @deprecated
     * @param request - The request {@link GlobalApiGetCurrentPlanRequest}
     * @returns A Promise of Plan
     */
    getCurrentPlan: (request?: Readonly<GlobalApiGetCurrentPlanRequest>) => Promise<Plan>;
}
/**
 * Cockpit Regional API.
 *
 * The Cockpit Regional API allows you to create data sources and tokens to
 * store and query data types such as metrics, logs, and traces. You can also
 * push your data into Cockpit, and send alerts to your contact points when your
 * resources may require your attention, using the regional Alert manager.
 */
export declare class RegionalAPI extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: ScwRegion[];
    /**
     * Get the Cockpit configuration.
     *
     * @param request - The request {@link RegionalApiGetConfigRequest}
     * @returns A Promise of GetConfigResponse
     */
    getConfig: (request?: Readonly<RegionalApiGetConfigRequest>) => Promise<GetConfigResponse>;
    /**
     * Create a data source. You must specify the data source type upon creation.
     * Available data source types include:
     *
     * - Metrics
     * - Logs
     * - Traces The name of the data source will then be used as reference to name
     *   the associated Grafana data source.
     *
     * @param request - The request {@link RegionalApiCreateDataSourceRequest}
     * @returns A Promise of DataSource
     */
    createDataSource: (request: Readonly<RegionalApiCreateDataSourceRequest>) => Promise<DataSource>;
    /**
     * Get a data source. Retrieve information about a given data source,
     * specified by the data source ID. The data source's information such as its
     * name, type, URL, origin, and retention period, is returned.
     *
     * @param request - The request {@link RegionalApiGetDataSourceRequest}
     * @returns A Promise of DataSource
     */
    getDataSource: (request: Readonly<RegionalApiGetDataSourceRequest>) => Promise<DataSource>;
    /**
     * Delete a data source. Delete a given data source, specified by the data
     * source ID. Note that deleting a data source is irreversible, and cannot be
     * undone.
     *
     * @param request - The request {@link RegionalApiDeleteDataSourceRequest}
     */
    deleteDataSource: (request: Readonly<RegionalApiDeleteDataSourceRequest>) => Promise<void>;
    protected pageOfListDataSources: (request?: Readonly<RegionalApiListDataSourcesRequest>) => Promise<ListDataSourcesResponse>;
    /**
     * List data sources. Retrieve the list of data sources available in the
     * specified region. By default, the data sources returned in the list are
     * ordered by creation date, in ascending order. You can list data sources by
     * Project, type and origin.
     *
     * @param request - The request {@link RegionalApiListDataSourcesRequest}
     * @returns A Promise of ListDataSourcesResponse
     */
    listDataSources: (request?: Readonly<RegionalApiListDataSourcesRequest>) => Promise<ListDataSourcesResponse> & {
        all: () => Promise<DataSource[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<DataSource[], void, void>;
    };
    /**
     * Update a data source. Update a given data source name, specified by the
     * data source ID.
     *
     * @param request - The request {@link RegionalApiUpdateDataSourceRequest}
     * @returns A Promise of DataSource
     */
    updateDataSource: (request: Readonly<RegionalApiUpdateDataSourceRequest>) => Promise<DataSource>;
    /**
     * Get data source usage overview. Retrieve the data source usage overview per
     * type for the specified Project.
     *
     * @param request - The request {@link RegionalApiGetUsageOverviewRequest}
     * @returns A Promise of UsageOverview
     */
    getUsageOverview: (request?: Readonly<RegionalApiGetUsageOverviewRequest>) => Promise<UsageOverview>;
    /**
     * Create a token. Give your token the relevant scopes to ensure it has the
     * right permissions to interact with your data sources and the Alert manager.
     * Make sure that you create your token in the same regions as the data
     * sources you want to use it for. Upon creation, your token's secret key
     * display only once. Make sure that you save it.
     *
     * @param request - The request {@link RegionalApiCreateTokenRequest}
     * @returns A Promise of Token
     */
    createToken: (request: Readonly<RegionalApiCreateTokenRequest>) => Promise<Token>;
    protected pageOfListTokens: (request?: Readonly<RegionalApiListTokensRequest>) => Promise<ListTokensResponse>;
    /**
     * List tokens. Retrieve a list of all tokens in the specified region. By
     * default, tokens returned in the list are ordered by creation date, in
     * ascending order. You can filter tokens by Project ID and token scopes.
     *
     * @param request - The request {@link RegionalApiListTokensRequest}
     * @returns A Promise of ListTokensResponse
     */
    listTokens: (request?: Readonly<RegionalApiListTokensRequest>) => Promise<ListTokensResponse> & {
        all: () => Promise<Token[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Token[], void, void>;
    };
    /**
     * Get a token. Retrieve information about a given token, specified by the
     * token ID. The token's information such as its scopes, is returned.
     *
     * @param request - The request {@link RegionalApiGetTokenRequest}
     * @returns A Promise of Token
     */
    getToken: (request: Readonly<RegionalApiGetTokenRequest>) => Promise<Token>;
    /**
     * Delete a token. Delete a given token, specified by the token ID. Deleting a
     * token is irreversible and cannot be undone.
     *
     * @param request - The request {@link RegionalApiDeleteTokenRequest}
     */
    deleteToken: (request: Readonly<RegionalApiDeleteTokenRequest>) => Promise<void>;
    /**
     * Get the Alert manager. Retrieve information about the Alert manager which
     * is unique per Project and region. By default the Alert manager is disabled.
     * The output returned displays a URL to access the Alert manager, and whether
     * the Alert manager and managed alerts are enabled.
     *
     * @param request - The request {@link RegionalApiGetAlertManagerRequest}
     * @returns A Promise of AlertManager
     */
    getAlertManager: (request?: Readonly<RegionalApiGetAlertManagerRequest>) => Promise<AlertManager>;
    /**
     * Enable the Alert manager. Enabling the Alert manager allows you to enable
     * managed alerts and create contact points in the specified Project and
     * region, to be notified when your Scaleway resources may require your
     * attention.
     *
     * @param request - The request {@link RegionalApiEnableAlertManagerRequest}
     * @returns A Promise of AlertManager
     */
    enableAlertManager: (request?: Readonly<RegionalApiEnableAlertManagerRequest>) => Promise<AlertManager>;
    /**
     * Disable the Alert manager. Disabling the Alert manager deletes the contact
     * points you have created and disables managed alerts in the specified
     * Project and region.
     *
     * @param request - The request {@link RegionalApiDisableAlertManagerRequest}
     * @returns A Promise of AlertManager
     */
    disableAlertManager: (request?: Readonly<RegionalApiDisableAlertManagerRequest>) => Promise<AlertManager>;
    /**
     * Create a contact point. Contact points are email addresses associated with
     * the default receiver, that the Alert manager sends alerts to. The source of
     * the alerts are data sources within the same Project and region as the Alert
     * manager. If you need to receive alerts for other receivers, you can create
     * additional contact points and receivers in Grafana. Make sure that you
     * select the Scaleway Alert manager.
     *
     * @param request - The request {@link RegionalApiCreateContactPointRequest}
     * @returns A Promise of ContactPoint
     */
    createContactPoint: (request?: Readonly<RegionalApiCreateContactPointRequest>) => Promise<ContactPoint>;
    protected pageOfListContactPoints: (request?: Readonly<RegionalApiListContactPointsRequest>) => Promise<ListContactPointsResponse>;
    /**
     * List contact points. Retrieve a list of contact points for the specified
     * Project. The response lists all contact points and receivers created in
     * Grafana or via the API.
     *
     * @param request - The request {@link RegionalApiListContactPointsRequest}
     * @returns A Promise of ListContactPointsResponse
     */
    listContactPoints: (request?: Readonly<RegionalApiListContactPointsRequest>) => Promise<ListContactPointsResponse> & {
        all: () => Promise<ContactPoint[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<ContactPoint[], void, void>;
    };
    updateContactPoint: (request?: Readonly<RegionalApiUpdateContactPointRequest>) => Promise<ContactPoint>;
    /**
     * Delete a contact point. Delete a contact point associated with the default
     * receiver.
     *
     * @param request - The request {@link RegionalApiDeleteContactPointRequest}
     */
    deleteContactPoint: (request?: Readonly<RegionalApiDeleteContactPointRequest>) => Promise<void>;
    /**
     * List alerts. List preconfigured and/or custom alerts for the specified
     * Project.
     *
     * @param request - The request {@link RegionalApiListAlertsRequest}
     * @returns A Promise of ListAlertsResponse
     */
    listAlerts: (request?: Readonly<RegionalApiListAlertsRequest>) => Promise<ListAlertsResponse>;
    /**
     * Enable managed alerts. Enable the sending of managed alerts for the
     * specified Project. Managed alerts are predefined alerts that apply to
     * Scaleway recources integrated with Cockpit by default.
     *
     * @param request - The request {@link RegionalApiEnableManagedAlertsRequest}
     * @returns A Promise of AlertManager
     */
    enableManagedAlerts: (request?: Readonly<RegionalApiEnableManagedAlertsRequest>) => Promise<AlertManager>;
    /**
     * Disable managed alerts. Disable the sending of managed alerts for the
     * specified Project.
     *
     * @param request - The request {@link RegionalApiDisableManagedAlertsRequest}
     * @returns A Promise of AlertManager
     */
    disableManagedAlerts: (request?: Readonly<RegionalApiDisableManagedAlertsRequest>) => Promise<AlertManager>;
    /**
     * Trigger a test alert. Send a test alert to the Alert manager to make sure
     * your contact points get notified.
     *
     * @param request - The request {@link RegionalApiTriggerTestAlertRequest}
     */
    triggerTestAlert: (request?: Readonly<RegionalApiTriggerTestAlertRequest>) => Promise<void>;
}
