import { isJSONObject } from "../../../helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject, resolveOneOf } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
const unmarshalLink = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Link' failed as data isn't a dictionary.`
    );
  }
  return {
    bandwidthMbps: data.bandwidth_mbps,
    bgpV4Status: data.bgp_v4_status,
    bgpV6Status: data.bgp_v6_status,
    createdAt: unmarshalDate(data.created_at),
    disapprovedReason: data.disapproved_reason,
    enableRoutePropagation: data.enable_route_propagation,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    pairingKey: data.pairing_key,
    partnerId: data.partner_id,
    popId: data.pop_id,
    projectId: data.project_id,
    region: data.region,
    routingPolicyId: data.routing_policy_id,
    status: data.status,
    tags: data.tags,
    updatedAt: unmarshalDate(data.updated_at),
    vpcId: data.vpc_id
  };
};
const unmarshalPartner = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Partner' failed as data isn't a dictionary.`
    );
  }
  return {
    contactEmail: data.contact_email,
    createdAt: unmarshalDate(data.created_at),
    id: data.id,
    logoUrl: data.logo_url,
    name: data.name,
    portalUrl: data.portal_url,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalPop = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Pop' failed as data isn't a dictionary.`
    );
  }
  return {
    address: data.address,
    availableLinkBandwidthsMbps: data.available_link_bandwidths_mbps,
    city: data.city,
    hostingProviderName: data.hosting_provider_name,
    id: data.id,
    logoUrl: data.logo_url,
    name: data.name,
    region: data.region
  };
};
const unmarshalRoutingPolicy = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'RoutingPolicy' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    prefixFilterIn: data.prefix_filter_in,
    prefixFilterOut: data.prefix_filter_out,
    projectId: data.project_id,
    region: data.region,
    tags: data.tags,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalListLinksResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListLinksResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    links: unmarshalArrayOfObject(data.links, unmarshalLink),
    totalCount: data.total_count
  };
};
const unmarshalListPartnersResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPartnersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    partners: unmarshalArrayOfObject(data.partners, unmarshalPartner),
    totalCount: data.total_count
  };
};
const unmarshalListPopsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPopsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pops: unmarshalArrayOfObject(data.pops, unmarshalPop),
    totalCount: data.total_count
  };
};
const unmarshalListRoutingPoliciesResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListRoutingPoliciesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    routingPolicies: unmarshalArrayOfObject(
      data.routing_policies,
      unmarshalRoutingPolicy
    ),
    totalCount: data.total_count
  };
};
const marshalAttachRoutingPolicyRequest = (request, defaults) => ({
  routing_policy_id: request.routingPolicyId
});
const marshalAttachVpcRequest = (request, defaults) => ({
  vpc_id: request.vpcId
});
const marshalCreateLinkRequest = (request, defaults) => ({
  bandwidth_mbps: request.bandwidthMbps,
  name: request.name,
  pop_id: request.popId,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags,
  ...resolveOneOf([
    { param: "dedicated", value: request.dedicated },
    { param: "port_id", value: request.portId },
    { param: "partner_id", value: request.partnerId }
  ])
});
const marshalCreateRoutingPolicyRequest = (request, defaults) => ({
  name: request.name,
  prefix_filter_in: request.prefixFilterIn,
  prefix_filter_out: request.prefixFilterOut,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags
});
const marshalUpdateLinkRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
const marshalUpdateRoutingPolicyRequest = (request, defaults) => ({
  name: request.name,
  prefix_filter_in: request.prefixFilterIn,
  prefix_filter_out: request.prefixFilterOut,
  tags: request.tags
});
export {
  marshalAttachRoutingPolicyRequest,
  marshalAttachVpcRequest,
  marshalCreateLinkRequest,
  marshalCreateRoutingPolicyRequest,
  marshalUpdateLinkRequest,
  marshalUpdateRoutingPolicyRequest,
  unmarshalLink,
  unmarshalListLinksResponse,
  unmarshalListPartnersResponse,
  unmarshalListPopsResponse,
  unmarshalListRoutingPoliciesResponse,
  unmarshalPartner,
  unmarshalPop,
  unmarshalRoutingPolicy
};
